import request from '../../utils/request'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    buildings: {},
    detail: {}
  },
  mutations: {
    updateList (state, payload) {
      state.buildings = payload
    },
    updateDetail (state, payload) {
      state.detail = payload
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', {})
    },
    getBuildings ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        request({
          ...apis.building.list,
          params: payload,
        }).then((data) => {
          window.console.log(data)
          commit('updateList', { ...data, list: data.records})
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    getDetail ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        request({
          ...apis.building.detail,
          urlData: payload,
        }).then((data) => {
          window.console.log(data)
          commit('updateDetail', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    addBuilding (_, payload) {
      const { onSuccess } = payload
      request({
        ...apis.building.add,
        data: payload.detail,
      }).then((data) => {
        onSuccess(data)
      })
    },
    editBuilding (_, payload) {
      const { onSuccess } = payload
      request({
        ...apis.building.edit,
        urlData: { id: payload.detail.buildingId },
        data: payload.detail
      }).then((data) => {
        onSuccess(data)
      })
    },
    delBuilding (_, payload) {
      return new Promise((resolve, reject) => {
        request({
          ...apis.building.delete,
          urlData: payload,
        }).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    updateBuildingStatus (_, payload) {
      return new Promise((resolve, reject) => {
        request({
          ...apis.building.updateStatus,
          data: payload,
        }).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    }
  }
}
